Learn R Programming

benford.analysis (version 0.1.3)

census.2009: Population data of Towns and Cities of the US - 2009

Description

A dataset containing the population of towns and cities of the United States, as of july of 2009.

Arguments

format

A data frame with 19509 rows and 3 variables

References

Nigrini, M. J. (2012). Benford's Law: Application for Forensic Accounting, Auditing and Fraud Detection. Wiley and Sons: New Jersey.