Learn R Programming

benford.analysis (version 0.1.3)

lakes.perimeter: Perimeter of lakes arround the world

Description

A dataset of the perimeter of the lakes arround the water from the global lakes and wetlands database (GLWD).

Arguments

format

A data frame with 248607 rows and 1 variable.

References

Nigrini, M. J. (2012). Benford's Law: Application for Forensic Accounting, Auditing and Fraud Detection. Wiley and Sons: New Jersey.