Learn R Programming

benford.analysis (version 0.1.3)

mantissa: Gets the main stats of the Mantissa of a Benford object

Description

It gets the Mean, Variance, Excess Kurtosis and Skewness of the Mantissa. See the section value of benford.

Usage

mantissa(bfd)

Arguments

bfd
an object of class "Benford". See benford.

Value

  • A data.frame with the main stats of the Mantissa.

Examples

Run this code
data(corporate.payment) #gets data 
cp <- benford(corporate.payment$Amount) #generates benford object
mantissa(cp) # equivalent to cp$mantissa

Run the code above in your browser using DataLab